import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl =
'https://gist.githubusercontent.com/BVNPK001/2ff8ac6738381de05694aaa445c822f5/raw/446c4e6334620d097e9f41e26964f84bf38373a6/students.csv';

const width = 960;
const height = 500;
const margin = { top: 20, right: 20, bottom: 50, left: 200 };



const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
             d.Score = +d['Grade'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 20));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map(d => d.Name))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.Score)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="green" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 9}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
      
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            stroke="green"
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.Name}
            x={0}
            y={yScale(d.Name)}
            width={xScale(d.Score)}
            height={yScale.bandwidth()}
            fill="orange"
            stroke="blue"
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);